import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger

mongodb_util = MongodbUtil('27017')

from mns_common.db.MongodbUtilLocal import MongodbUtil as MongodbUtilLocal

mongodbUtilLocal = MongodbUtilLocal('27017')

db_name_list = [
    # 'company_info', 'company_info_base', 'company_info_his', 'company_info_hk', 'de_list_stock',
    # 'em_stock_asset_liability',
    # 'em_stock_profit',
    # 'k_line_info',
    # 'kpl_best_choose_daily',
    # 'kpl_best_choose_his',
    # 'kpl_best_choose_index',
    # 'kpl_best_choose_index_detail',
    # 'kpl_his_quotes',
    # 'stock_qfq_daily',
    # 'stock_qfq_monthly',
    # 'stock_qfq_weekly',
    # 'stock_gdfx_free_top_10',
    # 'recent_hot_stocks',
    # 'self_black_stock',
    # 'self_choose_plate', 'self_choose_stock', 'sse_info_uid',
    # 'stock_high_chg_pool', 'stock_interactive_question',
    # 'stock_zt_pool', 'stock_zt_pool_five', 'stock_zb_pool', 'sw_industry',
    # 'ths_concept_list', 'ths_stock_concept_detail','ths_zt_pool',
    # 'today_new_concept_list',
    # 'trade_date_list',
    # 'ths_stock_concept_detail_app',
    "stock_zt_pool"
]


def sync_collection_to_local():
    for db_name in db_name_list:
        try:
            df_data = mongodb_util.find_all_data(db_name)
            mongodbUtilLocal.save_mongo(df_data, db_name)
            logger.info("同步到集合:{}", db_name)
        except BaseException as e:
            logger.error("出现异常:{}", e)


if __name__ == '__main__':
    sync_collection_to_local()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from loguru import logger

db_name_list = [
    # 'company_info', 'company_info_base', 'company_info_his', 'company_info_hk', 'de_list_stock',
    # 'em_stock_asset_liability',
    # 'em_stock_profit',
    # 'k_line_info',
    'kpl_best_choose_daily', 'kpl_best_choose_his', 'kpl_best_choose_index',
    'kpl_best_choose_index_detail',
    'kpl_his_quotes', 'recent_hot_stocks', 'self_black_stock', 'self_choose_plate', 'self_choose_stock', 'sse_info_uid',
    'stock_gdfx_free_top_10', 'stock_high_chg_pool', 'stock_interactive_question', 'stock_qfq_daily',
    'stock_qfq_monthly', 'stock_qfq_weekly', 'stock_zt_pool', 'stock_zt_pool_five', 'stock_zb_pool', 'sw_industry',
    'ths_concept_list', 'ths_stock_concept_detail', 'ths_stock_concept_detail_app', 'ths_zt_pool',
    'today_new_concept_list',
    'trade_date_list', 'realtime_quotes_now_zt_new', 'realtime_quotes_now_open', 'realtime_quotes_now_zt_new_kc_open']


def db_export(db, col):
    cmd = 'F:/mongo/bin/mongodump.exe --host ' + db + ' -d patience -c ' + col + ' -o D:/back'
    os.system(cmd)
    logger.info("export finished:{}", col)


def db_import(db, col):
    cmd = 'F:/mongo/bin/mongorestore.exe --host ' + db + ' -d patience -c ' + col + ' D:/back/patience/' + col + '.bson'
    os.system(cmd)

    path = 'D:\\back\\patience\\' + col + '.bson'
    cmd_del = 'del /F /S /Q ' + path
    os.system(cmd_del)

    logger.info("import finished:{}", col)


def collection_to_local():
    for db_name in db_name_list:
        try:
            db_export('127.0.0.1:27017', db_name)
            db_import('192.168.1.6:27017', db_name)
            logger.info("同步到集合:{}", db_name)
        except BaseException as e:
            logger.error("出现异常:{}", e)


if __name__ == '__main__':
    collection_to_local()



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 16
project_path = file_path[0:end]
sys.path.append(project_path)
from mns_common.db.MongodbUtil import MongodbUtil
from loguru import logger

mongodb_util = MongodbUtil('27017')
from mns_common.db.MongodbUtilLocal import MongodbUtil as MongodbUtilLocal

mongodbUtilLocal = MongodbUtilLocal('27017')


def sync_remote_open_data(str_day):
    query_remote = {"str_day": str_day}
    realtime_quotes_now_open_df = mongodb_util.find_query_data('realtime_quotes_now_open', query_remote)
    mongodbUtilLocal.insert_mongo(realtime_quotes_now_open_df, 'realtime_quotes_now_open')


if __name__ == '__main__':
    query = {'$and': [{"_id": {"$gte": "2022-03-16"}},
                      {"_id": {"$lte": "2024-06-28"}}]}
    trade_date_list = mongodb_util.find_query_data('trade_date_list', query)
    for trade_one in trade_date_list.itertuples():
        try:
            sync_str_day = trade_one.trade_date
            sync_remote_open_data(sync_str_day)
            logger.info('str_day:{}', sync_str_day)
        except BaseException as e:
            logger.error("同步远程数据异常:{}", e)



import sys
import os

file_path = os.path.abspath(__file__)
end = file_path.index('mns') + 17
project_path = file_path[0:end]
sys.path.append(project_path)
import pandas as pd
import mns_common.api.akshare.stock_zt_pool_api as stock_zt_pool_api
import mns_common.api.ths.zt.ths_stock_zt_pool_api as ths_stock_zt_pool_api
import mns_common.utils.date_handle_util as date_handle_util
import mns_common.component.concept.ths_concept_common_service_api as ths_concept_common_service_api
from mns_common.db.MongodbUtil import MongodbUtil
import mns_common.component.company.company_common_service_api as company_common_service_api
from loguru import logger
import mns_common.utils.data_frame_util as data_frame_util
import mns_common.component.common_service_fun_api as common_service_fun_api
import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api

'''
东方财富涨停池
'''

mongodb_util = MongodbUtil('27017')

ZT_FIELD = ['_id', 'symbol', 'name', 'now_price', 'chg', 'first_closure_time',
            'last_closure_time', 'connected_boards_numbers',
            'zt_reason', 'closure_funds',
            # 'closure_funds_per_amount', 'closure_funds_per_flow_mv',
            'frying_plates_numbers',
            # 'statistics_detail', 'zt_type', 'market_code',
            'statistics',
            # 'zt_flag',
            'industry', 'first_sw_industry',
            'second_sw_industry',
            'third_sw_industry', 'ths_concept_name',
            'ths_concept_code', 'ths_concept_sync_day', 'em_industry',
            'mv_circulation_ratio', 'ths_concept_list_info', 'kpl_plate_name',
            'kpl_plate_list_info', 'company_type', 'diff_days', 'symbol', 'amount',
            'quantity_ratio', 'high', 'low', 'high', 'low', 'open', 'list_date',
            'exchange', 'wei_bi', 'flow_mv', 'total_mv', 'buy_1_num',
            'classification', 'flow_mv_sp', 'total_mv_sp', 'flow_mv_level',
            'amount_level', 'new_stock', 'list_date_01', 'index', 'str_day']


def save_zt_info(str_day):
    if bool(1 - trade_date_common_service_api.is_trade_day(str_day)):
        return None

    stock_em_zt_pool_df_data = stock_zt_pool_api.stock_em_zt_pool_df(
        date_handle_util.no_slash_date(str_day))

    stock_em_zt_pool_df_data = common_service_fun_api.total_mv_classification(stock_em_zt_pool_df_data)

    stock_em_zt_pool_df_data = common_service_fun_api.classify_symbol(stock_em_zt_pool_df_data)

    stock_em_zt_pool_df_data = common_service_fun_api.symbol_amount_simple(stock_em_zt_pool_df_data)

    stock_em_zt_pool_df_data = company_common_service_api.amendment_industry(stock_em_zt_pool_df_data)
    try:
        # 同花顺问财涨停池
        ths_zt_pool_df_data = ths_stock_zt_pool_api.get_real_time_zt_info()

        # del stock_em_zt_pool_df_data['ths_concept_name']
        # del stock_em_zt_pool_df_data['ths_concept_code']

        for stock_one in stock_em_zt_pool_df_data.itertuples():
            try:
                stock_em_zt_pool_df_data = ths_concept_common_service_api.set_last_ths_concept(stock_one.symbol,
                                                                                               stock_em_zt_pool_df_data,
                                                                                               str_day)
                ths_zt_pool_one_df = ths_zt_pool_df_data.loc[ths_zt_pool_df_data['symbol'] == stock_one.symbol]
                if data_frame_util.is_empty(ths_zt_pool_one_df):
                    continue
                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'zt_reason'] = \
                    list(ths_zt_pool_one_df['zt_reason'])[0]

                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'quantity_ratio'] = \
                    list(ths_zt_pool_one_df['quantity_ratio'])[0]
                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'high'] = \
                    list(ths_zt_pool_one_df['high'])[0]
                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'low'] = \
                    list(ths_zt_pool_one_df['low'])[0]
                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'open'] = \
                    list(ths_zt_pool_one_df['open'])[0]

                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'wei_bi'] = \
                    list(ths_zt_pool_one_df['wei_bi'])[0]

                stock_em_zt_pool_df_data.loc[stock_em_zt_pool_df_data['symbol'] == stock_one.symbol, 'buy_1_num'] = \
                    list(ths_zt_pool_one_df['buy_1_num'])[0]

            except BaseException as e:
                logger.error("出现异常:{}", e)
    except BaseException as e:
        stock_em_zt_pool_df_data['zt_reason'] = ''
        stock_em_zt_pool_df_data['quantity_ratio'] = 0
        stock_em_zt_pool_df_data['high'] = 0
        stock_em_zt_pool_df_data['low'] = 0
        stock_em_zt_pool_df_data['open'] = 0
        stock_em_zt_pool_df_data['wei_bi'] = 0
        stock_em_zt_pool_df_data['buy_1_num'] = 0
        logger.error("出现异常:{}", e)

    stock_em_zt_pool_df_data['list_date'] = stock_em_zt_pool_df_data['list_date'].apply(
        lambda x: pd.to_numeric(x, errors="coerce"))

    stock_em_zt_pool_df_data['new_stock'] = False
    # 将日期数值转换为日期时间格式
    stock_em_zt_pool_df_data['list_date_01'] = pd.to_datetime(stock_em_zt_pool_df_data['list_date'], format='%Y%m%d')
    str_day_date = date_handle_util.str_to_date(str_day, '%Y-%m-%d')
    # 计算日期差值 距离现在上市时间
    stock_em_zt_pool_df_data['diff_days'] = stock_em_zt_pool_df_data.apply(
        lambda row: (str_day_date - row['list_date_01']).days, axis=1)
    # 上市时间小于100天为新股
    stock_em_zt_pool_df_data.loc[
        stock_em_zt_pool_df_data["diff_days"] < 100, ['new_stock']] \
        = True
    stock_em_zt_pool_df_data = stock_em_zt_pool_df_data.dropna(subset=['diff_days'], axis=0, inplace=False)

    # 按照"time"列进行排序，同时将值为0的数据排到最末尾
    stock_em_zt_pool_df_data = stock_em_zt_pool_df_data.sort_values(by=['first_closure_time'])

    # 重置索引，并将排序结果保存到新的"index"列中

    stock_em_zt_pool_df_data['str_day'] = str_day
    stock_em_zt_pool_df_data['_id'] = stock_em_zt_pool_df_data['symbol'] + "_" + str_day

    stock_em_zt_pool_df_data = stock_em_zt_pool_df_data[ZT_FIELD]
    mongodb_util.save_mongo(stock_em_zt_pool_df_data, 'stock_zt_pool')
    return stock_em_zt_pool_df_data


if __name__ == '__main__':
    save_zt_info('2024-07-22')
# from datetime import datetime
#
# if __name__ == '__main__':
#
#     sync_date = date_handle_util.add_date_day('20240110', 0)
#
#     now_date = datetime.now()
#
#     str_now_day = sync_date.strftime('%Y-%m-%d')
#
#     while now_date > sync_date:
#         try:
#             save_zt_info(str_now_day)
#             sync_date = date_handle_util.add_date_day(date_handle_util.no_slash_date(str_now_day), 1)
#             print(str_now_day)
#             str_now_day = sync_date.strftime('%Y-%m-%d')
#
#         except BaseException as e:
#             sync_date = date_handle_util.add_date_day(date_handle_util.no_slash_date(str_now_day), 1)
#             str_now_day = sync_date.strftime('%Y-%m-%d')
